# -*- coding: utf-8 -*-

from __future__ import (absolute_import, division, print_function)
__metaclass__ = type

DOCUMENTATION = '''
  name: dir_files_sort
  short_description: Sort a list according to numerical order instead of pure alphabetical one
  version_added: ovirt-ansible-collection-3.0
  author:
  description:
    - Sort a list according to numerical order instead of pure alphabetical one.
  options:
    _input:
      description: A list of strings to sort.
      type: list
      elements: string
      required: true
'''

EXAMPLES = '''
- name: Convert list of tuples into dictionary
  ansible.builtin.set_fact:
    dictionary: "{{ ['2.1', '2.10', '2.9'] | ovirt.ovirt.dir_files_sort }}"
    # Result is ['2.1', '2.9', '2.10']
'''

RETURN = '''
  _value:
    description: The list of strings sorted by version.
    type: list
    elements: string
'''


def dir_files_sort(l):
    l.sort(key=lambda f: int(''.join(filter(str.isdigit, f))))
    return l


class FilterModule(object):
    ''' String Numeric sort filter '''

    def filters(self):
        return {
            'dir_files_sort': dir_files_sort
        }
